pub struct Records { /* private fields */ }Expand description
A chunk’s worth of records, as ranges into the buffer they were read from.
One list of fields for all of the records and one list of where each record’s fields end, which is two allocations that are reused from chunk to chunk rather than one per row.
Implementations